@@ -407,7 +407,7 @@ AddressBook::AddressBook(TQWidget* parent, const char* name, bool loadit)
     entries(new StringKabKeyMap),
     state(NoFile)
 {
-  register bool GUARD; GUARD=true;
+  bool GUARD; GUARD=true;
   // ###########################################################################
   TQString dir, filename;
   bool createBackup=true;
@@ -647,7 +647,7 @@ AddressBook::ErrorCode AddressBook::load(const TQString& filename)
 AddressBook::ErrorCode
 AddressBook::getListOfNames(TQStringList* strings, bool reverse, bool initials)
 {
-  register bool GUARD; GUARD=false;
+  bool GUARD; GUARD=false;
   // ###########################################################################
   kdDebug(GUARD, KAB_KDEBUG_AREA) << "AddressBook::getListOfNames: called.\n";
   StringKabKeyMap::iterator pos;
@@ -702,7 +702,7 @@ AddressBook::literalName(const KabKey& key, TQString& text, bool rev, bool init)
 AddressBook::ErrorCode
 AddressBook::literalName(const Entry& entry, TQString& text, bool rev, bool init)
 {
-  register bool GUARD; GUARD=false;
+  bool GUARD; GUARD=false;
   // ###########################################################################
   kdDebug(GUARD, KAB_KDEBUG_AREA) << "AddressBook::literalName: called.\n";
   TQString firstname, middlename, lastname, nameprefix;
@@ -817,7 +817,7 @@ AddressBook::dataFileChanged()
 void
 AddressBook::configFileChanged()
 {
-  register bool GUARD; GUARD=true;
+  bool GUARD; GUARD=true;
   // ###########################################################################
   if(!config->load())
     {
@@ -835,7 +835,7 @@ AddressBook::configFileChanged()
 void
 AddressBook::reloaded(QConfigDB* db)
 {
-  register bool GUARD; GUARD=false;
+  bool GUARD; GUARD=false;
   // ###########################################################################
   if(db==data)
       {
@@ -924,7 +924,7 @@ AddressBook::getEntry(const KabKey& key, Entry& entry)
 AddressBook::ErrorCode
 AddressBook::getEntry(const KabKey& key, Section*& section)
 {
-  register bool GUARD; GUARD=false;
+  bool GUARD; GUARD=false;
   // ###########################################################################
   kdDebug(GUARD, KAB_KDEBUG_AREA) << "AddressBook::getEntry: searching entry "
       "with key " << key.getKey().data() << endl;
@@ -1004,7 +1004,7 @@ AddressBook::getKey(int index, KabKey& key)
 AddressBook::ErrorCode
 AddressBook::getIndex(const KabKey& key, int& index)
 {
-  register bool GUARD; GUARD=true;
+  bool GUARD; GUARD=true;
   // ###########################################################################
   StringKabKeyMap::iterator pos;
   // -----
@@ -1283,7 +1283,7 @@ AddressBook::nextAvailEntryKey()
 AddressBook::ErrorCode
 AddressBook::updateMirrorMap()
 {
-  register bool GUARD; GUARD=false;
+  bool GUARD; GUARD=false;
   // ###########################################################################
   kdDebug(GUARD, KAB_KDEBUG_AREA) 
     << "AddressBook::updateMirrorMap: updating mirror map.\n";
