@@ -294,13 +294,15 @@ static void kDebugBackend( unsigned short nLevel, unsigned int nArea, const char
   const int BUFSIZE = 4096;
   char buf[BUFSIZE];
   if ( !kDebug_data->aAreaName.isEmpty() ) {
-      strlcpy( buf, kDebug_data->aAreaName.data(), BUFSIZE );
-      strlcat( buf, ": ", BUFSIZE );
+      strlcpy( buf, TQDateTime::currentDateTime().toString("[yyyy/MM/dd hh:mm:ss.zzz] [").ascii(), BUFSIZE );
+      strlcat( buf, kDebug_data->aAreaName.data(), BUFSIZE );
+      strlcat( buf, "] ", BUFSIZE );
+      strlcat( buf, data, BUFSIZE );
+  }
+  else {
+      strlcpy( buf, TQDateTime::currentDateTime().toString("[yyyy/MM/dd hh:mm:ss.zzz] ").ascii(), BUFSIZE );
       strlcat( buf, data, BUFSIZE );
   }
-  else
-      strlcpy( buf, data, BUFSIZE );
-
 
   // Output
   switch( nOutput )
