@@ -1976,7 +1976,7 @@ TQString TDELocale::formatDateTime(const TQDateTime &pDateTime,
 
 TQString i18n(const char* text)
 {
-  register TDELocale *instance = TDEGlobal::locale();
+  TDELocale *instance = TDEGlobal::locale();
   if (instance)
     return instance->translate(text);
   return TQString::fromUtf8(text);
@@ -1984,7 +1984,7 @@ TQString i18n(const char* text)
 
 TQString i18n(const char* index, const char *text)
 {
-  register TDELocale *instance = TDEGlobal::locale();
+  TDELocale *instance = TDEGlobal::locale();
   if (instance)
     return instance->translate(index, text);
   return TQString::fromUtf8(text);
@@ -1992,7 +1992,7 @@ TQString i18n(const char* index, const char *text)
 
 TQString i18n(const char* singular, const char* plural, unsigned long n)
 {
-  register TDELocale *instance = TDEGlobal::locale();
+  TDELocale *instance = TDEGlobal::locale();
   if (instance)
     return instance->translate(singular, plural, n);
   if (n == 1)
