@@ -2031,11 +2031,11 @@ void TransparencyHandler::rightShadow(TQImage& dst)
 	// blend top-right corner.
 	int pixels = dst.width() * dst.height();
 #ifdef WORDS_BIGENDIAN
-	register unsigned char* data = dst.bits() + 1;	// Skip alpha
+	unsigned char* data = dst.bits() + 1;	// Skip alpha
 #else
-	register unsigned char* data = dst.bits();		// Skip alpha
+	unsigned char* data = dst.bits();		// Skip alpha
 #endif
-	for(register int i = 0; i < 16; i++) {
+	for(int i = 0; i < 16; i++) {
 		if (have_composite) {
 			data++;
 			data++;
@@ -2051,8 +2051,8 @@ void TransparencyHandler::rightShadow(TQImage& dst)
 	}
 
 	pixels -= 32;	// tint right strip without rounded edges.
-	register int c = 0;
-	for(register int i = 0; i < pixels; i++) {
+	int c = 0;
+	for(int i = 0; i < pixels; i++) {
 		if (have_composite) {
 			data++;
 			data++;
@@ -2070,7 +2070,7 @@ void TransparencyHandler::rightShadow(TQImage& dst)
 	}
 
 	// tint bottom edge
-	for(register int i = 0; i < 16; i++) {
+	for(int i = 0; i < 16; i++) {
 		if (have_composite) {
 			data++;
 			data++;
@@ -2099,15 +2099,15 @@ void TransparencyHandler::bottomShadow(TQImage& dst)
 	double* corner = const_cast<double*>(bottom_left_corner);
 
 #ifdef WORDS_BIGENDIAN
-	register unsigned char* data = dst.bits() + 1;	// Skip alpha
+	unsigned char* data = dst.bits() + 1;	// Skip alpha
 #else
-	register unsigned char* data = dst.bits();	// Skip alpha
+	unsigned char* data = dst.bits();	// Skip alpha
 #endif
 
 	for(int y = 0; y < 4; y++)
 	{
 		// Bottom-left Corner
-		for(register int x = 0; x < 4; x++) {
+		for(int x = 0; x < 4; x++) {
 			if (have_composite) {
 				data++;
 				data++;
@@ -2124,7 +2124,7 @@ void TransparencyHandler::bottomShadow(TQImage& dst)
 		}
 
 		// Scanline
-		for(register int x = 0; x < width; x++) {
+		for(int x = 0; x < width; x++) {
 			if (have_composite) {
 				data++;
 				data++;
