@@ -1034,10 +1034,11 @@ bool KFileItem::cmp( const KFileItem & item )
              && m_bLink == item.m_bLink
              && m_hidden == item.m_hidden
              && size(hasSize1) == item.size(hasSize2)
-	     && hasSize1 == hasSize2
+             && hasSize1 == hasSize2
              && time(TDEIO::UDS_MODIFICATION_TIME, hasTime1) == item.time(TDEIO::UDS_MODIFICATION_TIME, hasTime2)
-	     && hasTime1 == hasTime2
-             && (!d || !item.d || d->iconName == item.d->iconName) );
+             && hasTime1 == hasTime2
+             && (!d || !item.d || d->iconName == item.d->iconName)
+             && (!isMimeTypeKnown() || !item.isMimeTypeKnown() || mimetype() == item.mimetype()) );
 
     // Don't compare the mimetypes here. They might not be known, and we don't want to
     // do the slow operation of determining them here.
@@ -1078,6 +1079,8 @@ void KFileItem::assign( const KFileItem & item )
             d = new KFileItemPrivate;
         }
         d->iconName = item.d->iconName;
+        d->comment = item.d->comment;
+        d->commentCached = item.d->commentCached;
     } else {
         delete d;
         d = 0;
